@@ -1,6 +1,11 @@
 require 'spec_helper'
 
 describe 'glance::api' do
+  let :pre_condition do
+    "class { '::glance::api::authtoken':
+      password => 'ChangeMe',
+    }"
+  end
 
   let :default_params do
     {
@@ -18,7 +23,6 @@ describe 'glance::api' do
       :manage_service           => true,
       :backlog                  => '<SERVICE DEFAULT>',
       :workers                  => '7',
-      :keystone_password        => 'ChangeMe',
       :show_image_direct_url    => '<SERVICE DEFAULT>',
       :show_multiple_locations  => '<SERVICE DEFAULT>',
       :location_strategy        => '<SERVICE DEFAULT>',
@@ -32,13 +36,21 @@ describe 'glance::api' do
       :image_cache_max_size     => '<SERVICE DEFAULT>',
       :os_region_name           => 'RegionOne',
       :pipeline                 => 'keystone',
+      :task_time_to_live        => '<SERVICE DEFAULT>',
+      :task_executor            => '<SERVICE DEFAULT>',
+      :task_work_dir            => '<SERVICE DEFAULT>',
+      :taskflow_engine_mode     => '<SERVICE DEFAULT>',
+      :taskflow_max_workers     => '<SERVICE DEFAULT>',
+      :conversion_format        => '<SERVICE DEFAULT>',
+      :enable_v1_api            => '<SERVICE DEFAULT>',
+      :enable_v2_api            => '<SERVICE DEFAULT>',
+      :sync_db                  => true,
     }
   end
 
   shared_examples_for 'glance::api' do
 
-    [{:keystone_password => 'ChangeMe'},
-     {
+    [{
         :debug                    => true,
         :bind_host                => '127.0.0.1',
         :bind_port                => '9222',
@@ -49,7 +61,6 @@ describe 'glance::api' do
         :enabled                  => false,
         :backlog                  => '4095',
         :workers                  => '5',
-        :keystone_password        => 'ChangeMe',
         :show_image_direct_url    => true,
         :show_multiple_locations  => true,
         :location_strategy        => 'store_type',
@@ -60,6 +71,7 @@ describe 'glance::api' do
         :image_cache_max_size     => '10737418240',
         :os_region_name           => 'RegionOne2',
         :pipeline                 => 'keystone2',
+        :sync_db                  => false,
       }
     ].each do |param_set|
 
@@ -78,6 +90,13 @@ describe 'glance::api' do
         it { is_expected.to contain_class 'glance::api::logging' }
         it { is_expected.to contain_class 'glance::api::db' }
 
+        it 'is_expected.to not sync the db if sync_db is set to false' do
+
+          if !param_hash[:sync_db]
+            is_expected.not_to contain_exec('glance-manage db_sync')
+          end
+        end
+
         it { is_expected.to contain_service('glance-api').with(
           'ensure'     => (param_hash[:manage_service] && param_hash[:enabled]) ? 'running': 'stopped',
           'enable'     => param_hash[:enabled],
@@ -103,6 +122,8 @@ describe 'glance::api' do
             'delayed_delete',
             'scrub_time',
             'image_cache_dir',
+            'enable_v1_api',
+            'enable_v2_api',
           ].each do |config|
             is_expected.to contain_glance_api_config("DEFAULT/#{config}").with_value(param_hash[config.intern])
           end
@@ -128,6 +149,15 @@ describe 'glance::api' do
           end
         end
 
+        it 'is_expected.to lay down default task & taskflow_executor config' do
+          is_expected.to contain_glance_api_config('task/task_time_to_live').with_value(param_hash[:task_time_to_live])
+          is_expected.to contain_glance_api_config('task/task_executor').with_value(param_hash[:task_executor])
+          is_expected.to contain_glance_api_config('task/work_dir').with_value(param_hash[:task_work_dir])
+          is_expected.to contain_glance_api_config('taskflow_executor/engine_mode').with_value(param_hash[:taskflow_engine_mode])
+          is_expected.to contain_glance_api_config('taskflow_executor/max_workers').with_value(param_hash[:taskflow_max_workers])
+          is_expected.to contain_glance_api_config('taskflow_executor/conversion_format').with_value(param_hash[:conversion_format])
+        end
+
         it 'is_expected.to have no ssl options' do
           is_expected.to contain_glance_api_config('DEFAULT/ca_file').with_value('<SERVICE DEFAULT>')
           is_expected.to contain_glance_api_config('DEFAULT/cert_file').with_value('<SERVICE DEFAULT>')
@@ -149,9 +179,8 @@ describe 'glance::api' do
     describe 'with disabled service managing' do
       let :params do
         {
-          :keystone_password => 'ChangeMe',
-          :manage_service    => false,
-          :enabled           => false,
+          :manage_service => false,
+          :enabled        => false,
         }
       end
 
@@ -167,8 +196,7 @@ describe 'glance::api' do
     describe 'with overridden pipeline' do
       let :params do
         {
-          :keystone_password => 'ChangeMe',
-          :pipeline          => 'something',
+          :pipeline => 'something',
         }
       end
 
@@ -178,8 +206,7 @@ describe 'glance::api' do
     describe 'with blank pipeline' do
       let :params do
         {
-          :keystone_password => 'ChangeMe',
-          :pipeline          => '',
+          :pipeline => '',
         }
       end
 
@@ -234,6 +261,7 @@ describe 'glance::api' do
         it { is_expected.to contain_glance_api_config('DEFAULT/registry_client_cert_file').with_value('/tmp/registry_cert_file') }
       end
     end
+
     describe 'with stores by default' do
       let :params do
         default_params
@@ -302,6 +330,28 @@ describe 'glance::api' do
       it { is_expected.to contain_glance_api_config('glance_store/stores').with_value('file') }
     end
 
+    describe 'with task & taskflow configuration' do
+      let :params do
+        default_params.merge({
+          :task_time_to_live    => 72,
+          :task_executor        => 'taskflow-next-gen',
+          :task_work_dir        => '/tmp/large',
+          :taskflow_engine_mode => 'serial',
+          :taskflow_max_workers => 1,
+          :conversion_format    => 'raw',
+        })
+      end
+
+      it 'is_expected.to lay down default task & taskflow_executor config' do
+        is_expected.to contain_glance_api_config('task/task_time_to_live').with_value(72)
+        is_expected.to contain_glance_api_config('task/task_executor').with_value('taskflow-next-gen')
+        is_expected.to contain_glance_api_config('task/work_dir').with_value('/tmp/large')
+        is_expected.to contain_glance_api_config('taskflow_executor/engine_mode').with_value('serial')
+        is_expected.to contain_glance_api_config('taskflow_executor/max_workers').with_value(1)
+        is_expected.to contain_glance_api_config('taskflow_executor/conversion_format').with_value('raw')
+      end
+    end
+
     describe 'while validating the service with default command' do
       let :params do
         default_params.merge({
@@ -351,32 +401,6 @@ describe 'glance::api' do
         :require => 'Exec[execute glance-api validation]',
       )}
     end
-
-    describe 'with deprecated auth parameters' do
-      let :params do
-        default_params.merge({
-          :auth_type         => 'keystone',
-          :keystone_tenant   => 'services',
-          :keystone_user     => 'glance',
-          :keystone_password => 'password',
-          :token_cache_time  => '1000',
-          :memcached_servers => 'localhost:11211',
-          :signing_dir       => '/tmp/keystone',
-          :auth_uri          => 'http://127.0.0.1:5000',
-          :identity_uri      => 'http://127.0.0.1:35357',
-        })
-      end
-      it 'deprecated auth parameters' do
-        is_expected.to contain_glance_api_config('keystone_authtoken/memcached_servers').with_value(params[:memcached_servers])
-        is_expected.to contain_glance_api_config('keystone_authtoken/username').with_value(params[:keystone_user])
-        is_expected.to contain_glance_api_config('keystone_authtoken/project_name').with_value(params[:keystone_tenant])
-        is_expected.to contain_glance_api_config('keystone_authtoken/password').with_value(params[:keystone_password])
-        is_expected.to contain_glance_api_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
-        is_expected.to contain_glance_api_config('keystone_authtoken/signing_dir').with_value(params[:signing_dir])
-        is_expected.to contain_glance_api_config('keystone_authtoken/auth_uri').with_value(params[:auth_uri])
-        is_expected.to contain_glance_api_config('keystone_authtoken/auth_url').with_value(params[:identity_uri])
-      end
-    end
   end
 
   shared_examples_for 'glance::api Debian' do
